@@ -54,11 +54,20 @@ def _get_root_dir() -> str:
     return os.path.abspath(os.path.dirname(__file__))
 
 
-def visualize(local_dataset: Union[Dataset, FusionDataset]) -> None:
+def visualize(
+    local_dataset: Union[Dataset, FusionDataset],
+    host: str = "127.0.0.1",
+    port: int = 5000,
+    debug: bool = False,
+) -> None:
     """This is the starter of pharos app.
 
     Arguments:
-         local_dataset: The local dataset.
+        local_dataset: The local dataset.
+        host: The hostname to listen on. Set this to ``'0.0.0.0'`` to
+            have the server available externally as well.
+        port: The port of the webserver.
+        debug: Whether to enable debug mode.
 
     Raises:
         TypeError: When the dataset is not a Dataset or FusionDataset.
@@ -68,7 +77,7 @@ def visualize(local_dataset: Union[Dataset, FusionDataset]) -> None:
         raise TypeError("It is not a Dataset or FusionDataset.")
 
     PHAROS_DATASET.set_dataset(local_dataset)
-    app.run()
+    app.run(host, port, debug)
 
 
 @app.route("/")
@@ -266,7 +275,7 @@ class DataUriList(Resource):  # type: ignore[misc]
         segment_name = args["segmentName"]
 
         try:
-            segment = PHAROS_DATASET.dataset.get_segment_by_name(segment_name)
+            segment = PHAROS_DATASET.dataset[segment_name]
         except KeyError:
             abort(404, f"Segment:'{segment_name}' does not exist.")
 
@@ -351,7 +360,7 @@ class LabelList(Resource):  # type: ignore[misc]
         sort_by = args["sortBy"]
         segment_name = args["segmentName"]
         try:
-            segment = PHAROS_DATASET.dataset.get_segment_by_name(segment_name)
+            segment = PHAROS_DATASET.dataset[segment_name]
         except KeyError:
             abort(404, f"Segment:'{segment_name}' does not exist.")
 
@@ -424,7 +433,7 @@ class SensorList(Resource):  # type: ignore[misc]
         segment_name = args["segmentName"]
 
         try:
-            segment = PHAROS_DATASET.dataset.get_segment_by_name(segment_name)
+            segment = PHAROS_DATASET.dataset[segment_name]
         except KeyError:
             abort(404, f"Segment:'{segment_name}' does not exist.")
 
